==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebPaneHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebPaneHeaderElementDescription } from "./WebPaneHeaderElementDescription";
/**
 * @hidden
 */
export let WebPaneHeaderElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderElementDescriptionMetadata.a == null) {
                WebPaneHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderElementDescriptionMetadata.c(WebPaneHeaderElementDescriptionMetadata.a);
            }
            if (a.j(WebPaneHeaderElementDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPaneHeaderElementDescriptionMetadata.a);
            WebDragServiceDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderElement");
            a.item("DragService", "ExportedType:WebDragService");
        }
        static d(a) {
            WebPaneHeaderElementDescriptionMetadata.b(a);
            a.aa("WebPaneHeaderElement", () => new WebPaneHeaderElementDescription());
            a.z("WebPaneHeaderElement", WebPaneHeaderElementDescriptionMetadata.a);
        }
    }
    WebPaneHeaderElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderElementDescriptionMetadata, 'WebPaneHeaderElementDescriptionMetadata');
    WebPaneHeaderElementDescriptionMetadata.a = null;
    return WebPaneHeaderElementDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebPaneHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebPaneHeaderElementDescription } from "./WebPaneHeaderElementDescription";
/**
 * @hidden
 */
export let WebPaneHeaderElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderElementDescriptionMetadata.a == null) {
                WebPaneHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderElementDescriptionMetadata.c(WebPaneHeaderElementDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderElementDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPaneHeaderElementDescriptionMetadata.a);
            WebDragServiceDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderElement");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("DragService", "ExportedType:WebDragService");
        }
        static d(a) {
            WebPaneHeaderElementDescriptionMetadata.b(a);
            a.ac("WebPaneHeaderElement", () => new WebPaneHeaderElementDescription());
            a.ab("WebPaneHeaderElement", WebPaneHeaderElementDescriptionMetadata.a);
        }
    }
    WebPaneHeaderElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderElementDescriptionMetadata, 'WebPaneHeaderElementDescriptionMetadata');
    WebPaneHeaderElementDescriptionMetadata.a = null;
    return WebPaneHeaderElementDescriptionMetadata;
})();
